pub enum CommandError {
SendCommand(Command, String),
ReceiveResponse(Command, String),
}Variants
SendCommand(Command, String)
The command cannot be sent from this Projection to its projection.
ReceiveResponse(Command, String)
A response for the command cannot be received from this Projection’s projection.